pm4py.algo.filtering package
============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.filtering.common
   pm4py.algo.filtering.dfg
   pm4py.algo.filtering.log
   pm4py.algo.filtering.ocel
   pm4py.algo.filtering.pandas

Module contents
---------------

.. automodule:: pm4py.algo.filtering
   :members:
   :undoc-members:
   :show-inheritance:
